@@ -27,7 +27,7 @@ except:
     print "Replacing gethostname()"
     socket.gethostname = lambda: 'localhost'
 
-from .ppapi_simple import NaClInstance
+from .ppapi_wrapper import NaClInstance
 nacl_instance = NaClInstance()
 nacl_instance.pylab()
 
